@@ -96,6 +96,7 @@ class Item(object):
     SKIP_REASON_NO_TRIGGER = 6
     SKIP_REASON_SOFTLOCK = 7
     SKIP_REASON_UNLESS = 8
+    SKIP_REASON_DEP_SKIPPED = 9
     SKIP_REASON_DESC = {
         SKIP_REASON_CMDLINE: _("cmdline"),
         SKIP_REASON_DEP_FAILED: _("dependency failed"),
@@ -105,6 +106,7 @@ class Item(object):
         SKIP_REASON_NO_TRIGGER: _("not triggered"),
         SKIP_REASON_SOFTLOCK: _("soft locked"),
         SKIP_REASON_UNLESS: _("unless"),
+        SKIP_REASON_DEP_SKIPPED: _("dependency skipped"),
     }
     STATUS_OK = 1
     STATUS_FIXED = 2
@@ -416,6 +418,7 @@ class Item(object):
     def apply(
         self,
         autoskip_selector="",
+        autoonly_selector="",
         my_soft_locks=(),
         other_peoples_soft_locks=(),
         interactive=False,
@@ -431,6 +434,13 @@ class Item(object):
         status_after = None
         start_time = datetime.now()
 
+        if not self.covered_by_autoonly_selector(autoonly_selector):
+            io.debug(_(
+                "autoonly does not match {item} on {node}"
+            ).format(item=self.id, node=self.node.name))
+            status_code = self.STATUS_SKIPPED
+            skip_reason = self.SKIP_REASON_CMDLINE
+
         if self.covered_by_autoskip_selector(autoskip_selector):
             io.debug(_(
                 "autoskip matches {item} on {node}"
@@ -621,6 +631,35 @@ class Item(object):
                 return True
         return False
 
+    def covered_by_autoonly_selector(self, autoonly_selector):
+        """
+        True if this item should be NOT skipped based on the given selector
+        string (e.g. "tag:foo,bundle:bar").
+        """
+        if not autoonly_selector:
+            return True
+        components = [c.strip() for c in autoonly_selector.split(",")]
+        if (
+            self.id in components or
+            "bundle:{}".format(self.bundle.name) in components or
+            "{}:".format(self.ITEM_TYPE_NAME) in components
+        ):
+            return True
+        for tag in self.tags:
+            if "tag:{}".format(tag) in components:
+                return True
+        for depending_item in self._incoming_deps:
+            if (
+                depending_item.id in components or
+                "bundle:{}".format(depending_item.bundle.name) in components or
+                "{}:".format(depending_item.ITEM_TYPE_NAME) in components
+            ):
+                return True
+            for tag in depending_item.tags:
+                if "tag:{}".format(tag) in components:
+                    return True
+        return False
+
     def fix(self, status):
         """
         This is supposed to actually implement stuff on the target node.
