@@ -15,9 +15,11 @@ from .deps import (
 )
 from .exceptions import (
     DontCache,
+    GracefulApplyException,
     ItemDependencyLoop,
     NodeLockedException,
     NoSuchBundle,
+    RemoteException,
     RepositoryError,
     SkipNode,
 )
@@ -104,7 +106,6 @@ def format_node_result(result):
 
 def handle_apply_result(node, item, status_code, interactive, details=None):
     if status_code == Item.STATUS_SKIPPED and details in (
-        Item.SKIP_REASON_CMDLINE,
         Item.SKIP_REASON_NO_TRIGGER,
         Item.SKIP_REASON_UNLESS,
     ):
@@ -128,6 +129,7 @@ def handle_apply_result(node, item, status_code, interactive, details=None):
 def apply_items(
     node,
     autoskip_selector="",
+    autoonly_selector="",
     my_soft_locks=(),
     other_peoples_soft_locks=(),
     workers=1,
@@ -151,6 +153,7 @@ def apply_items(
             'target': item.apply,
             'kwargs': {
                 'autoskip_selector': autoskip_selector,
+                'autoonly_selector': autoonly_selector,
                 'my_soft_locks': my_soft_locks,
                 'other_peoples_soft_locks': other_peoples_soft_locks,
                 'interactive': interactive,
@@ -179,7 +182,7 @@ def apply_items(
             item_queue.item_ok(item)
         elif status_code == Item.STATUS_SKIPPED:
             for skipped_item in item_queue.item_skipped(item):
-                skip_reason = Item.SKIP_REASON_DEP_FAILED
+                skip_reason = Item.SKIP_REASON_DEP_SKIPPED
                 for lock in other_peoples_soft_locks:
                     for selector in lock['items']:
                         if skipped_item.covered_by_autoskip_selector(selector):
@@ -542,6 +545,7 @@ class Node(object):
     def apply(
         self,
         autoskip_selector="",
+        autoonly_selector="",
         interactive=False,
         force=False,
         skip_list=tuple(),
@@ -590,29 +594,47 @@ class Node(object):
             x=blue("i"),
         ))
 
+        error = False
+
         try:
-            with NodeLock(self, interactive=interactive, ignore=force) as lock:
-                item_results = apply_items(
-                    self,
-                    autoskip_selector=autoskip_selector,
-                    my_soft_locks=lock.my_soft_locks,
-                    other_peoples_soft_locks=lock.other_peoples_soft_locks,
-                    workers=workers,
-                    interactive=interactive,
-                )
-        except NodeLockedException as e:
-            if not interactive:
-                io.stderr(_(
-                    "{x} {node} already locked by {user} at {date} ({duration} ago, "
-                    "`bw apply -f` to override)"
-                ).format(
-                    date=bold(e.args[0]['date']),
-                    duration=e.args[0]['duration'],
-                    node=bold(self.name),
-                    user=bold(e.args[0]['user']),
-                    x=red("!"),
-                ))
+            # Running "true" is meant to catch connection errors early,
+            # but this only works on UNIX-y systems (i.e., not k8s).
+            if self.os in self.OS_FAMILY_UNIX:
+                self.run("true")
+        except RemoteException as exc:
+            io.stdout(_("{x} {node}  Connection error: {msg}").format(
+                msg=exc,
+                node=bold(self.name),
+                x=red("!"),
+            ))
+            error = _("Connection error (details above)")
             item_results = []
+        else:
+            try:
+                with NodeLock(self, interactive=interactive, ignore=force) as lock:
+                    item_results = apply_items(
+                        self,
+                        autoskip_selector=autoskip_selector,
+                        autoonly_selector=autoonly_selector,
+                        my_soft_locks=lock.my_soft_locks,
+                        other_peoples_soft_locks=lock.other_peoples_soft_locks,
+                        workers=workers,
+                        interactive=interactive,
+                    )
+            except NodeLockedException as e:
+                if not interactive:
+                    io.stderr(_(
+                        "{x} {node} already locked by {user} at {date} ({duration} ago, "
+                        "`bw apply -f` to override)"
+                    ).format(
+                        date=bold(e.args[0]['date']),
+                        duration=e.args[0]['duration'],
+                        node=bold(self.name),
+                        user=bold(e.args[0]['user']),
+                        x=red("!"),
+                    ))
+                error = _("Node locked (details above)")
+                item_results = []
         result = ApplyResult(self, item_results)
         result.start = start
         result.end = datetime.now()
@@ -633,7 +655,10 @@ class Node(object):
             result=result,
         )
 
-        return result
+        if error:
+            raise GracefulApplyException(error)
+        else:
+            return result
 
     def download(self, remote_path, local_path):
         return operations.download(
@@ -835,6 +860,20 @@ def verify_items(node, show_all=False, workers=1):
         elif not isinstance(item, DummyItem):
             io.progress_advance()
 
+    try:
+        # See comment in node.apply().
+        if node.os in node.OS_FAMILY_UNIX:
+            node.run("true")
+    except RemoteException as exc:
+        io.stdout(_("{x} {node}  Connection error: {msg}").format(
+            msg=exc,
+            node=bold(node.name),
+            x=red("!"),
+        ))
+        for item in items:
+            io.progress_advance()
+        return [None for item in items]
+
     def tasks_available():
         return bool(items)
 
